
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

#############################
Sample usage for collocations
#############################

.. include:: ../../nltk/test/collocations.doctest